#!/usr/bin/env python2.7
# Copyright 2015 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Distribute/Setuptools installer for MAAS Image Builder."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

str = None

from os.path import (
    dirname,
    join,
    )

from setuptools import (
    find_packages,
    setup,
    )

# The source tree's location in the filesystem.
SOURCE_DIR = dirname(__file__)


def read(filename):
    """Return the whitespace-stripped content of `filename`."""
    path = join(SOURCE_DIR, filename)
    with open(path, "rb") as fin:
        return fin.read().strip()


__version__ = "0.9"

setup(
    name="maas-image-builder",
    version=__version__,
    url="https://launchpad.net/maas-image-builder",
    license="AGPLv3",
    description="MAAS Image Builder",
    long_description=read('README'),

    author="Blake Rouse",
    author_email="blake.rouse@canonical.com",

    packages=find_packages(
        where=b'src',
        exclude=[
            b"*.testing",
            b"*.tests",
            ],
        ),
    package_dir={'': b'src'},
    include_package_data=True,

    entry_points={
        'mib.builder': [
            'centos = mib.builders.centos:CentOSBuilder',
            'rhel = mib.builders.rhel:RHELBuilder',
        ],
    },

    data_files=[
        ('/usr/bin',
            ['bin/maas-image-builder']),
    ],

    install_requires=[
        'python-stevedore'
        ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        "Intended Audience :: System Administrators",
        'License :: OSI Approved :: GPL License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        ],
    extras_require=dict(
        tests=[
            'coverage',
            'fixtures',
            'mock',
            'nose',
            'python-subunit',
            'testresources',
            'testscenarios',
            'testtools',
            ],
    )
)
