# Copyright 2014-2015 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

import logging
import os
import sys
import traceback

from mib.parser import load_parser
from stevedore.extension import ExtensionManager

# Enable basic logging to console.
logging.basicConfig()


def execute():
    """Main execution of the application."""
    # Check that have root privledges
    if os.geteuid() != 0:
        print('Error: must run with root privileges.')
        sys.exit(1)

    # Load all extensions.
    manager = ExtensionManager("mib.builder", invoke_on_load=True)
    builders = {
        extension.obj.name: extension.obj
        for extension in manager
        }

    # Load and parse the arguments.
    parser = load_parser(builders.values())
    args = parser.parse_args()

    # Check that the output directory exists.
    args.output = os.path.abspath(args.output)
    dirpath = os.path.dirname(args.output)
    if not os.path.exists(dirpath):
        print('Error: unable to write to output file in directory: %s' % (
            dirpath))
        sys.exit(1)

    # Build the image.
    builder = builders[args.builder]
    try:
        builder.build_image(args)
    except KeyboardInterrupt:
        sys.exit(1)
    except:
        traceback.print_exc()
        sys.exit(1)

    sys.exit(0)
