# Copyright 2014-2015 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

from argparse import ArgumentParser
import sys


def load_parser(builders):
    """Load command line parser with the sub-commands."""
    parser = ArgumentParser(
        description="Image builder for the Curtin installer.")
    parser.add_argument(
        '--vcpus',
        default="1", help="Number of vcpus to configure for the installation.")
    parser.add_argument(
        '-r', '--ram',
        default=2048, type=int, help="Memory to allocate for installation.")
    parser.add_argument(
        '-i', '--interface',
        default='virbr0', help="Bridge interface for created virtual machine.")
    parser.add_argument(
        '-a', '--arch',
        default='amd64', choices=['amd64', 'i386'],
        help="Architecture to build. Default: amd64")
    parser.add_argument(
        '-o', '--output', required=True,
        help="Output file for built image.")

    # Add sub-commands from the builders.
    subparser = parser.add_subparsers(dest="builder")
    for builder in builders:
        builder_parser = subparser.add_parser(builder.name)
        builder.populate_parser(builder_parser)
    return parser
