# Copyright 2014-2015 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

import subprocess

from mib import utils

# QEMU Architecture Mapping
ARCH_MAP = {
    'amd64': 'x86_64'
    }


def create_disk(path, size, format='qcow2'):
    """Creates disk using qemu-img."""
    args = [
        'qemu-img', 'create',
        '-f', format,
        path,
        '%sG' % size,
        ]
    utils.subp(args)


def install_location(name, ram, arch, vcpus, os_type, os_variant,
                     disk, network, location, initrd_inject=None,
                     extra_args=None, reboot=False, graphics=False,
                     force=True):
    """Spawns virt-install."""
    if arch in ARCH_MAP:
        arch = ARCH_MAP[arch]
    args = [
        'virt-install',
        '--name', name,
        '--ram', '%s' % ram,
        '--arch', arch,
        '--vcpus', vcpus,
        '--os-type', os_type,
        '--os-variant', os_variant,
        '--disk', disk,
        '--network', network,
        '--location', location,
        ]
    if initrd_inject is not None:
        args.append('--initrd-inject=%s' % initrd_inject)
    if extra_args is not None:
        args.append("--extra-args=%s" % extra_args)
    if not reboot:
        args.append('--noreboot')
    if not graphics:
        args.append('--nographics')
    if force:
        args.append('--force')
    subprocess.check_call(args)


def install_cdrom(name, ram, arch, vcpus, os_type, os_variant,
                  disk, network, cdrom, reboot=False, graphics=False,
                  force=True):
    """Spawns virt-install."""
    if arch in ARCH_MAP:
        arch = ARCH_MAP[arch]
    args = [
        'virt-install',
        '--name', name,
        '--ram', '%s' % ram,
        '--arch', arch,
        '--vcpus', vcpus,
        '--os-type', os_type,
        '--os-variant', os_variant,
        '--disk', disk,
        '--network', network,
        '--cdrom', cdrom,
        ]
    if not reboot:
        args.append('--noreboot')
    if not graphics:
        args.append('--nographics')
    if force:
        args.append('--force')
    subprocess.check_call(args)


def undefine(name):
    """Undefines the virtual machine from virsh without deleting
    the storage volume.
    """
    utils.subp(['virsh', 'undefine', name])
